OPTICAL_PORT = "Оптический порт"
RS485 = "RS-485"
TCP_IP = "TCP/IP"
NOT_DEFINED = "не определен"
INTERNAL_CRYSTAL = "внутренний кварцевый генератор"
MAINS_FREQUENCY_50_HZ = "от сети 50 Гц"
MAINS_FREQUENCY_60_HZ = "от сети 60 Гц"
GPS_GLOBAL_POSITIONING_SYSTEM = "от системы GPS (GLONASS)"
RADIO_CONTROLLED = "от радиосигналов точного времени"
CONTROL_MODE_0 = "Отсутствует. Объект управления разъединением всегда находится в состоянии «подключено»"
CONTROL_MODE_1 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(D), ручной(E)"
CONTROL_MODE_2 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(A), ручной(E)"
CONTROL_MODE_3 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(D), ручной(E)"
CONTROL_MODE_4 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(A), ручной(E)"
CONTROL_MODE_5 = "Отключение: удаленные(B, C), ручной(F), локальный(G) Переподключение: удаленный(D), ручной(E), локальный(H)"
CONTROL_MODE_6 = "Отключение: удаленные(B, C), локальный(G) Переподключение: удаленный(D), ручной(E), локальный(H)"
RU_CONTROL_MODE_129 = "Отключение: удаленные(B, C), ручной(F), локальный(M) Переподключение: удаленный(D), ручной(E)"
RU_CONTROL_MODE_130 = "Отключение: удаленные(B, C), ручной(F), локальный(M) Переподключение: удаленный(A), ручной(E)"
RU_CONTROL_MODE_131 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(D), ручной(E)"
RU_CONTROL_MODE_132 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(A)"
RU_CONTROL_MODE_133 = "Отключение: удаленные(B, C), локальный(M) Переподключение: удаленный(A), локальный(K)"
RU_CONTROL_MODE_134 = "Отключение: удаленные(B, C), локальный(M, S) Переподключение: удаленный(D), ручной(E), локальный(P)"
DISCONNECTED = "отключено"
CONNECTED = "включено"
READY_FOR_RECONNECTION = "Готово к переподключению"
NOT_REGISTERED = "не зарегистрирован"
REGISTERED_HOME_NETWORK = "зарегистрирован, домашняя сеть"
NOT_REGISTERED_BUT_MT = "не зарегистрирован, но MT в настоящее время ищет нового оператора для регистрации в"
REGISTRATION_DENIED = "регистрация отвергнута"
UNKNOWN = "неизвестно"
REGISTERED_ROAMING = "зарегистрирован, роуминг"
INACTIVE = "не aктивно"
INCOMING_CALL = "входящий звонок"
ACTIVE = "активно"
GPRS = "GPRS"
EDGE = "EDGE"
UMTS = "UMTS"
HSDPA = "HSDPA"
BAUD_300 = "300 бод"
BAUD_600 = "600 бод"
BAUD_1200 = "1200 бод"
BAUD_2400 = "2400 бод"
BAUD_4800 = "4800 бод"
BAUD_9600 = "9600 бод"
BAUD_19200 = "19200 бод"
BAUD_38400 = "38400 бод"
BAUD_57600 = "57600 бод"
BAUD_115200 = "115200 бод"
IMAGE_TRANSFER_NOT_INITIATED = "Передача данных не инициированна"
IMAGE_TRANSFER_INITIATED = "Передача данных инициированна"
IMAGE_VERIFICATION_INITIATED = "Проверка данных инициированна"
IMAGE_VERIFICATION_SUCCESSFUL = "Проверка данных пройдена"
IMAGE_VERIFICATION_FAILED = "Проверка данных неудачна"
IMAGE_ACTIVATION_INITIATED = "Активация данных инициированна"
IMAGE_ACTIVATION_SUCCESSFUL = "Активация данных пройдена"
IMAGE_ACTIVATION_FAILED = "Активация данных неудачна"
FIFO = "FIFO(первый пришел первый ушел)"
LIFO = "LIFO(последний пришел первый ушел)"
LARGEST = "наибольший"
SMALLEST = "наименьший"
NEAREST_TO_ZERO = "ближайший к нулю"
FAREST_FROM_ZERO = "дальний от нуля"
WRITE_ATTRIBUTE = "запись в атрибут"
EXECUTE_SPECIFIC_METHOD = "выполнить конкретный метод"
SCHEDULE_TYPE_1 = "Размер времени выполнения = 1; Подстановочный знак в дате разрешен"
SCHEDULE_TYPE_2 = "Размер времени выполнения = N; Все значения времени одинаковы, подстановочный знак на дате не допускается"
SCHEDULE_TYPE_3 = "Размер времени выполнения = N; Все значения времени одинаковы, подстановочный знак в дате разрешены"
SCHEDULE_TYPE_4 = "Размер времени выполнения = N; Значения времени могут быть разными, подстановочный знак даты не допускается"
SCHEDULE_TYPE_5 = "Размер времени выполнения = N; Значения времени могут быть разными, подстановочные знаки в дате разрешены"
NO_ACCESS = "нет доступа"
READ_ONLY = "только чтение"
WRITE_ONLY = "только запись"
READ_AND_WRITE = "чтение и запись"
NON_ASSOCIATED = "нет соединения"
ASSOCIATION_PENDING = "ожидание соединения"
ASSOCIATED = "соединение установлено"
NO_STATION = "Отсутствует"
CLIENT_MANAGEMENT_PROCESS = "Процесс управления клиентами"
PUBLIC_CLIENT = "Публичный клиент"
METER_READER = "Считыватель показаний"
UTILITY_SETTING = "Конфигуратор"
PUSH = "Инициативный"
FIRMWARE_UPDATE = "Обновление ПО"
IHD = "Домашний дисплей"
NONE = "Низший, без секретности"
LOW = "Низкий, без шифрования с паролем"
HIGH = "Высокий"
HIGH_MD5 = "Высокий, MD5"
HIGH_SHA1 = "Высокий, SHA1"
HIGH_GMAC = "Высокий, GMAC"
HIGH_SHA256 = "Высокий, SHA256"
HIGH_ECDSA = "Высокий, ECDSAL"
ACCESS = "доступно"
AUTHENTICATED_ACCESS = "доступ с проверкой подлинности"
NOTHING = "ничего не делать"
ALL_MESSAGES_TO_BE_AUTHENTICATION = "Все сообщения должны быть аутентифицированы"
ALL_MESSAGES_TO_BE_ENCRYPTED = "Все сообщения должны быть зашифрованы"
ALL_MESSAGES_TO_BE_AUTH_AND_ENC = "Все сообщения должны быть аутентифицированы и зашифрованы"
RESERVED = "зарезервировано"
AUTHENTICATION = "аутентификация"
AUTHENTICATION_REQUEST = "запрос с аутентификацией"
ENCRYPTION = "Шифрование"
AUTHENTICATION_AND_ENCRYPTION = "Аутентификация и шифрование"
DIGITAL_SIGNATURE = "Цифровая подпись"
ENCRYPTED_REQUEST = "зашифрованный запрос"
DIGITALLY_SIGNED_REQUEST = "запрос с цифровой подписью"
AUTHENTICATION_RESPONSE = "ответ с аутентификацией"
ENCRYPTED_RESPONSE = "зашифрованный ответ"
DIGITALLY_SIGNED_RESPONSE = "ответ с цифровой подписью"
UNUSED = "не используется, всегда 0"
AUTHENTICATION_READ_ONLY = "только чтение с проверкой подлинности"
AUTHENTICATION_WRITE_ONLY = "только запись с проверкой подлинности"
AUTHENTICATION_READ_AND_WRITE = "чтение и запись с проверкой подлинности"
TIME_YEAR = "год"
TIME_MONTH = "мес"
TIME_WEEK = "нед"
TIME_DAY = "дн"
TIME_HOUR = "ч"
TIME_MINUTE = "мин"
TIME_SECOND = "с"
PHASE_ANGLE_DEGREE = "°"
TEMPERATURE = "°C"
LOCAL_CURRENCY = "валюта"
LENGTH_METRE = "м"
SPEED_METRE_PER_SECOND = "м/с"
VOLUME_VALUE_CUBIC_METRE = "м³"
CORRECTED_VOLUME_CUBIC_METRE = "м³*"
VOLUME_FLUX_CUBIC_METRE_PER_HOUR = "м³/ч"
CORRECTED_VOLUME_FLUX_CUBIC_METRE_PER_HOUR = "м³/ч*"
VOLUME_FLUX_CUBIC_METRE_PER_DAY = "м³/дн"
CORRECTED_VOLUME_FLUX_CUBIC_METRE_PER_DAY = "м³/дн*"
VOLUME_LITRE = "л"
MASS_KILOGRAM = "кг"
FORCE_NEWTON = "Н"
ENERGY_NEWTON_METER = "Нм"
PRESSURE_PASCAL = "Па"
PRESSURE_BAR = "100000 Н/м²"
ENERGY_JOULE = "Дж"
THERMAL_POWER_RATE_OF_CHANGE_JOULE_PER_HOUR = "Дж/ч"
ACTIVE_POWER_WATT = "Вт"
APPARENT_POWER_VOLT_AMPERE = "В*А"
REACTIVE_POWER_VAR = "ВАР"
ACTIVE_ENERGY_VALUE_WATT_HOUR = "Вт*ч"
APPARENT_ENERGY_VALUE_VOLT_AMPERE_HOUR = "В*А*ч"
REACTIVE_ENERGY_VALUE_VAR_HOUR = "ВАР*ч"
CURRENT_AMPERE = "А"
ELECTRICAL_CHARGE_COULOMB = "К"
VOLTAGE_VOLT = "В"
ELECTRIC_FIELD_STRENGTH_VOLT_PER_METRE = "В/м"
CAPACITANCE_FARAD = "Ф"
RESISTANCE_OHM = "Ом"
RESISTIVITY = "Ом*м"
MAGNETIC_FLUX_WEBER = "Вб"
MAGNETIC_FLUX_DENSITY_TESLA = "Тл"
MAGNETIC_FIELD_STRENGTH_AMPERE_PER_METRE = "А/м"
INDUCTANCE_HENRY = "Гн"
FREQUENCY_HERTZ = "Гц"
RW_ACTIVE_ENERGY_VALUE = "1/(Вт*ч)"
RB_REACTIVE_ENERGY_VALUE = "1/(ВАР*ч)"
RS_APPARENT_ENERGY_VALUE = "1/(В*А*ч)"
VOLT_SQUARED_HOUR_VOLT_SQUARED_HOUR_METER = "В²*ч"
AMPERE_SQUARED_HOUR = "А²*ч"
MASS_FLUX_KILOGRAM_PER_SECOND = "кг/с"
CONDUCTANCE_SIEMENS = "См"
TEMPERATURE_KELVIN = "K"
RU2H_VOLT_SQUARED_HOUR_METER = "1/(В²*ч)"
RI2H_AMPERE_SQUARED_HOUR_METER = "1/(А²*ч)"
RV_METER = "1/м³"
PERCENTAGE = "%"
AMPERE_HOURS = "А*ч"
ENERGY_PER_VOLUME = "3600 Дж/м³"
CALORIFIC_VALUE_WOBBE = "Дж/м³"
MOLAR_FRACTION_OF_GAS_COMPOSITION_MOLE_PERCENT = "моль %"
MASS_DENSITY_QUANTITY_OF_MATERIAL = "г/м³"
DYNAMIC_VISCOSITY_PASCAL_SECOND = "Па*с"
SPECIFIC_ENERGY_JOULE_KILOGRAM = "Дж/кг"
PRESSURE_GRAM_PER_SQUARE_CENTIMETER = "г/см²"
PRESSURE_ATMOSPHERE = "атм"
SIGNAL_STRENGTH_MILLIWATT = "дБм"
SIGNAL_STRENGTH_MICROVOLT = "дБмкВ"
LOGARITHMIC_UNIT = "дБ"
LENGTH_INCH = "in"
LENGTH_FOOT = "ft"
MASS_POUND = "lb"
TEMPERATURE_FAHRENHEIT = "°F"
TEMPERATURE_RANKINE = "°R"
AREA_SQUARE_INCH = "sq. in"
AREA_SQUARE_FOOT = "sq ft"
AREA_ACRE = "ac"
VOLUME_CUBIC_INCH = "cu in"
VOLUME_CUBIC_FOOT = "cu ft"
VOLUME_ACRE_FOOT = "ac ft"
VOLUME_GALLON_IMPERIAL = "gal(imp)"
VOLUME_GALLON_US = "gal(US)"
FORCE_POUND_FORCE = "lbf"
PRESSURE_POUND_FORCE_PER_SQUARE_INCH = "psi"
DENSITY_POUND_PER_CUBIC_FOOT = "lb/cu ft"
DYNAMIC_VISCOSITY = "lb/(ft .s)"
KINEMATIC_VISCOSITY_SQUARE_FOOT_PER_SECOND = "sq ft/s"
ENERGY_BRITISH_THERMAL_UNIT = "Btu"
ENERGY_THERM_EU = "thm(EC)"
ENERGY_THERM_US = "thm(US)"
CALORIFIC_VALUE_OF_MASS_LENTHALPY = "Btu/lb"
CALORIFIC_VALUE_OF_VOLUME_WOBBE = "Btu/cu ft"
VOLUME_METER_CUBIC_FEET_RV = "cu ft rv"
SPEED_FOOT_PER_SECOND = "ft/s"
VOLUME_FLUX_CUBIC_FOOT_PER_SECOND = "cu ft/s"
VOLUME_FLUX_CUBIC_FOOT_PER_MIN = "cu ft/min"
VOLUME_FLUX_CUBIC_FOOT_PER_HOUR = "cu ft/h"
VOLUME_FLUX_CUBIC_FOOT_PER_DAY = "cu ft/d"
VOLUME_FLUX_ACRE_FOOT_PER_SECOND = "ac ft/s"
VOLUME_FLUX_ACRE_FOOT_PER_MIN = "ac ft/min"
VOLUME_FLUX_ACRE_FOOT_PER_HOUR = "ac ft/h"
VOLUME_FLUX_ACRE_FOOT_PER_DAY = "ac ft/d"
VOLUME_IMPERIAL_GALLON_METER_RV = "gal(imp) rv"
VOLUME_FLUX_IMPERIAL_GALLON_PER_SECOND = "gal(imp)/s"
VOLUME_FLUX_IMPERIAL_GALLON_PER_MIN = "gal(imp)/min"
VOLUME_FLUX_IMPERIAL_GALLON_PER_HOUR = "gal(imp)/h"
VOLUME_FLUX_IMPERIAL_GALLON_PER_DAY = "gal(imp)/d"
VOLUME_US_GALLON_RV = "gal(US) rv"
VOLUME_FLUX_US_GALLON_PER_SECOND = "gal(US)/s"
VOLUME_FLUX_US_GALLON_PER_MIN = "gal(US)/min"
VOLUME_FLUX_US_GALLON_PER_HOUR = "gal(US)/h"
VOLUME_FLUX_US_GALLON_PER_DAY = "gal(US)/d"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_SECOND = "Btu/s"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_MINUTE = "Btu/min"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_HOUR = "Btu/h"
ENERGY_FLOW_BRITISH_THERMAL_UNIT_PER_DAY = "Btu/d"
EXTENDED_TABLE_OF_UNITS = "расширенная"
OTHER_UNIT = "другое"
NO_UNIT_UNITLESS_COUNT = "ед"
GUEK = "Глобальный одноадресный ключ шифрования"
GBEK = "Глобальный широковещательный ключ шифрования"
GAK = "Ключ аутентификации"
KEK = "Мастер ключ"
AES_GCM_128 = "AES-GSM-128 аутентификация, шифрование и упаковка ключей"
AES_GCM_128_ECDSA_P_256 = "AES-GSM-128 аутентификация, шифрование, цифровая подпись, согласование ключей, хеширование, V.44 сжатие и упаковка ключей"
AES_GCM_256_ECDSA_P_384 = "AES-GSM-256 аутентификация, шифрование, цифровая подпись, согласование ключей, хеширование, V.44 сжатие и упаковка ключей"
SERVER = "Сервер"
CLIENT_OR_THIRD_PARTY = "Клиент"
CERTIFICATION_AUTHORITY = "Администратор"
OTHER = "Прочее"
KEY_AGREEMENT = "Соглосование ключей"
TLS = "TLS"
DIGITAL_SIGNATURE_KEY_PAIR = F"{DIGITAL_SIGNATURE} пары ключей"
KEY_AGREEMENT_KEY_PAIR = "Соглосование пары ключей"
TLS_KEY_PAIR = "TLS пары ключей"
CERTIFICATE_IDENTIFICATION_ENTITY = "Идентификация сертификата по объекту"
CERTIFICATE_IDENTIFICATION_SERIAL = "Идентификация сертификата по серийному номеру"
RESTRICTION_BY_DATE = "Ограничение по дате"
RESTRICTION_BY_ENTRY = "Ограничение по входу"
TCP = "TCP"
UDP = "UDP"
FTP_RESERVED = "зарезервированно для FTP"
SMTP_RESERVED = "зарезервированно для SMTP"
SMS = "SMS"
HDLC = "HDLC"
M_BUS = "M_BUS"
ZIGBEE_RESERVED = "зарезервированно для ZIGBEE"
DLMS_GATEWAY = "DLMS Gateway"
MANUFACTURER_SPECIFIC = "Спецификация производителя"
A_XDR = "A-XDR кодировка xDLMS APDU"
XML = "XML кодировка xDLMS APDU"
UNCONFIRMED_FAILURE = "Неподтвержденная, повторение при поддержке сбоя на уровне протокола"
UNCONFIRMED_MISSING = "Неподтверждено, повторение пропущенного подтверждения протокола"
CONFIRMED = "подтверждено, повторите пропущенное подтверждение"
MASTER_KEY = "мастер ключ"
GLOB_UNI_ENCR_KEY = "Глобальный ключ шифрования одноадресный"
GLOB_BROAD_ENCR_KEY = "Глобальный ключ шифрования широковещательный"
IDENTIFIED_KEY = "Идентификационный ключ"
WRAPPED_KEY = "Обернутый ключ"
AGREED_KEY = "Согласованный ключ"

# for GSM_diagnostic.cell_info
OR_LESS = "или менее"
OR_GREATER = "или более"
NOT_KNOWN_OR_NOT_DETECTABLE = "не известно или не опознано"



import setuptools

import src.DLMS_SPODES.settings


setuptools.setup(
    name="DlmsSPODES",
    version=src.DLMS_SPODES.settings.version(),
    long_description_content_type="text/markdown",
    url="https://github.com/youserj/DlmsSPODES",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License"
    ],
    entry_points={
        'console_scripts': [
            'parser=src.DlmsSPODES.setting:version'
        ]
    },
)



import unittest
from src.DLMS_SPODES.cosem_interface_classes.overview import ClassID
from src.DLMS_SPODES.types import ut


class TestType(unittest.TestCase):
    def test_CosemClassId(self):
        self.assertEqual(ClassID.DATA, ut.CosemClassId(1), "check ClassID enum")
        for i in filter(lambda it: isinstance(it, ut.CosemClassId), ClassID.__dict__.values()):
            print(i, i.__class__)



from ..types import common_data_types as cdt
from ..settings import get_current_language, Language


match get_current_language():
    case Language.ENGLISH: from ..Values.EN import events as e
    case Language.RUSSIAN: from ..Values.RU import events as e


class FlagEvents(dict):
    """ special class for flag events indication """
    def get_report(self, value: int) -> str:
        return '. '.join(filter(lambda it_: it_ is not None, map(lambda it: self.get(2 ** it, F"unknown bit: {it}"), filter(lambda it: value & 2 ** it, range(8)))))


class Events(dict):
    """ special class for enumerate events indication """
    def get_report(self, value: int) -> str:
        return F'{self.get(value, "error enum")}({value})'


voltage_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("VOLTAGE"), e.__dict__)))
"""for 0.0.96.11.0.255 События, связанные с напряжением ГОСТ Р 58940—2020 таблица Д.1"""
current_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("CURRENT"), e.__dict__)))
"""for current_events События, связанные с током ГОСТ Р 58940—2020 таблица Д.2"""
commutation_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("COMMUTATION"), e.__dict__)))
"""for 0.0.96.11.2.255 События, связанные с включением/выключением ПУ. коммутации реле нагрузки ГОСТ Р 58940—2020 таблица Д.3"""
programming_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("PROGRAMING"), e.__dict__)))
"""for 0.0.96.11.3.255 События программирования параметров ПУ ГОСТ Р 58940—2020 таблица Д.4"""
external_impact_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("EXTERNAL_IMPACT"), e.__dict__)))
"""for 0.0.96.11.4.255 События внешних воздействий ГОСТ Р 58940—2020 таблица Д.5"""
communication_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("COMMUNICATION"), e.__dict__)))
"""for 0.0.96.11.5.255 Коммуникационные события ГОСТ Р 58940—2020 таблица Д.6"""
access_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("ACCESS"), e.__dict__)))
"""for 0.0.96.11.6.255 События контроля доступа ГОСТ Р 58940—2020 таблица Д.7"""
self_diagnostics_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("SELF_DIAGNOSTIC"), e.__dict__)))
"""for 0.0.96.11.7.255 Коды событий для журнала самодиагностики ГОСТ Р 58940—2020 таблица Д.8"""
reactive_power_events = Events(tuple((int(key.split('_')[-1]), e.__dict__[key]) for key in filter(lambda i: i.startswith("REACTIVE_POWER"), e.__dict__)))
"""for 0.0.96.11.8.255 События по превышению реактивной мощности tg (ф) (тангенс сети) ГОСТ Р 58940—2020 таблица Д.9"""
power_quality_status_1 = FlagEvents(tuple((int(key.split('_')[-1], base=16), e.__dict__[key]) for key in filter(lambda i: i.startswith("POWER_QUALITY1"), e.__dict__)))
"""for 0.0.96.5.1.255 Статус качества сети (профиль суточных показаний) СТО 34.01-5.1-006-2021 таблица Е.2"""
power_quality_status_2 = FlagEvents(tuple((int(key.split('_')[-1], base=16), e.__dict__[key]) for key in filter(lambda i: i.startswith("POWER_QUALITY2"), e.__dict__)))
"""for 0.0.96.5.4.255 Статус качества сети (журнал качества сети) СТО 34.01-5.1-006-2021 таблица Е.1"""
